@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2019 by the individuals mentioned in the source code history
+#   Copyright 2007-2020 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -147,7 +147,7 @@ setParametersCheckVector <- function(values, test, argname, typename) {
 }
 
 
-omxSetParameters <- function(model, labels, free = NULL, values = NULL,
+omxSetParameters <- function(model, labels=names(coef(model)), free = NULL, values = NULL,
 	newlabels = NULL, lbound = NULL, ubound = NULL, indep = FALSE,
 	strict = TRUE, name = NULL) {
 	if (missing(labels) || !is.character(labels) || length(labels) == 0) {
@@ -162,6 +162,12 @@ omxSetParameters <- function(model, labels, free = NULL, values = NULL,
 	if (!is.null(name) && length(name) != 1 && !is.character(name)) {
 		stop("'name' argument must be a character string")
 	}
+	if (missing(free) && missing(values) && missing(newlabels) &&
+		    missing(lbound) && missing(ubound)) {
+		what <- c('free','values','newlabels','lbound','ubound')
+		warning(paste("What do you want to change?",
+			"Pick some of", omxQuotes(what)))
+	}
 	if (strict) {
 		pnames <- names(omxGetParameters(model, indep, NA))
 		missing <- setdiff(labels, pnames)
