@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2018 The OpenMx Project
+#   Copyright 2007-2018 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -68,9 +68,6 @@ omxCheckError(confint(biRegModelOut, parm="foobar"), "Parameter 'foobar' not rec
 
 ci <- confint(biRegModelOut)
 
-# ensure summary looks in model's runstate
-biRegModelOut$compute$steps[["GD"]]$engine <- 'XYZ'
-
 brmSum <- summary(biRegModelOut)
 omxCheckCloseEnough(brmSum$CFI, 1, 1e-5)
 omxCheckCloseEnough(brmSum$TLI, 1, 1e-6)
