@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2018 by the individuals mentioned in the source code history
+#   Copyright 2007-2020 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 
 
 library(OpenMx)
+library(testthat)
 
 #mxOption(NULL, "Default optimizer", "NPSOL")
 
@@ -27,7 +28,8 @@ model <- mxModel(model="con_test",
                  mxFitFunctionAlgebra("minK")
 )
 
-fit <- mxRun(model)
+fit <- expect_warning(mxRun(model),
+                      "no basis could be found for the nullspace of the constraint Jacobian")
 
 omxCheckCloseEnough(fit$output$fit, 1, 1e-4)
 omxCheckCloseEnough(c(fit$matrices$K$values), 1:4, 1e-3)
