@@ -6,6 +6,7 @@
 
 #ifdef EXTRA_GCC_DIAG
 #pragma GCC diagnostic warning "-Wshadow"
+#pragma GCC diagnostic warning "-Wpedantic"
 #pragma GCC diagnostic warning "-Wmisleading-indentation"
 #pragma GCC diagnostic warning "-Wall"
 #pragma GCC diagnostic warning "-Wextra"
@@ -13,9 +14,8 @@
 #pragma GCC diagnostic warning "-Wunused-function"
 #pragma GCC diagnostic warning "-Wunused-local-typedefs"
 #pragma GCC diagnostic warning "-Wdeprecated-declarations"
-#pragma GCC diagnostic warning "-Wignored-attributes"
 #pragma GCC diagnostic warning "-Wint-in-bool-context"
 #pragma GCC diagnostic warning "-Wstrict-aliasing"
 #pragma GCC diagnostic warning "-Wunused-variable"
-#pragma GCC diagnostic warning "-Wignored-attributes"
+#pragma GCC diagnostic warning "-Wsuggest-override"
 #endif
