@@ -1,5 +1,5 @@
-#ifndef _LOAD_DATA_API_H_
-#define _LOAD_DATA_API_H_
+#ifndef u_LOAD_DATA_API_H_
+#define u_LOAD_DATA_API_H_
 
 #include <memory>
 
@@ -68,11 +68,11 @@ protected:
 
 public:
 	const std::vector< int > &getColumns() { return columns; }
-	void commonInit(SEXP rObj, const char *_name,
-                  const char *_dataName, int rows,
-                  std::vector<ColumnData> &_rawCols,
-                  ColMapType &_rawColMap,
-                  std::vector< std::string > &_checkpointValues,
+	void commonInit(SEXP rObj, const char *u_name,
+                  const char *u_dataName, int rows,
+                  std::vector<ColumnData> &u_rawCols,
+                  ColMapType &u_rawColMap,
+                  std::vector< std::string > &u_checkpointValues,
                   bool useOriginalData);
 	virtual int getNumVariants() { return 0; }
 	bool wantCheckpoint() const { return checkpoint; }
